package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.GradTableMapper;
import com.ruoyi.system.domain.GradTable;
import com.ruoyi.system.service.IGradTableService;

/**
 * A类Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-11-25
 */
@Service
public class GradTableServiceImpl implements IGradTableService 
{
    @Autowired
    private GradTableMapper gradTableMapper;

    /**
     * 查询A类
     * 
     * @param id A类主键
     * @return A类
     */
    @Override
    public GradTable selectGradTableById(Long id)
    {
        return gradTableMapper.selectGradTableById(id);
    }

    /**
     * 查询A类列表
     * 
     * @param gradTable A类
     * @return A类
     */
    @Override
    public List<GradTable> selectGradTableList(GradTable gradTable)
    {
        return gradTableMapper.selectGradTableList(gradTable);
    }

    /**
     * 新增A类
     * 
     * @param gradTable A类
     * @return 结果
     */
    @Override
    public int insertGradTable(GradTable gradTable)
    {
        return gradTableMapper.insertGradTable(gradTable);
    }

    /**
     * 修改A类
     * 
     * @param gradTable A类
     * @return 结果
     */
    @Override
    public int updateGradTable(GradTable gradTable)
    {
        return gradTableMapper.updateGradTable(gradTable);
    }

    /**
     * 批量删除A类
     * 
     * @param ids 需要删除的A类主键
     * @return 结果
     */
    @Override
    public int deleteGradTableByIds(Long[] ids)
    {
        return gradTableMapper.deleteGradTableByIds(ids);
    }

    /**
     * 删除A类信息
     * 
     * @param id A类主键
     * @return 结果
     */
    @Override
    public int deleteGradTableById(Long id)
    {
        return gradTableMapper.deleteGradTableById(id);
    }
}
