package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GradTable;
import com.ruoyi.system.service.IGradTableService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * A类Controller
 * 
 * @author ruoyi
 * @date 2022-11-25
 */
@RestController
@RequestMapping("/system/grad")
public class GradTableController extends BaseController
{
    @Autowired
    private IGradTableService gradTableService;

    /**
     * 查询A类列表
     */
    @PreAuthorize("@ss.hasPermi('system:grad:list')")
    @GetMapping("/list")
    public TableDataInfo list(GradTable gradTable)
    {
        startPage();
        List<GradTable> list = gradTableService.selectGradTableList(gradTable);
        return getDataTable(list);
    }

    /**
     * 导出A类列表
     */
    @PreAuthorize("@ss.hasPermi('system:grad:export')")
    @Log(title = "A类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GradTable gradTable)
    {
        List<GradTable> list = gradTableService.selectGradTableList(gradTable);
        ExcelUtil<GradTable> util = new ExcelUtil<GradTable>(GradTable.class);
        util.exportExcel(response, list, "A类数据");
    }

    /**
     * 获取A类详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:grad:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gradTableService.selectGradTableById(id));
    }

    /**
     * 新增A类
     */
    @PreAuthorize("@ss.hasPermi('system:grad:add')")
    @Log(title = "A类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GradTable gradTable)
    {
        return toAjax(gradTableService.insertGradTable(gradTable));
    }

    /**
     * 修改A类
     */
    @PreAuthorize("@ss.hasPermi('system:grad:edit')")
    @Log(title = "A类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GradTable gradTable)
    {
        return toAjax(gradTableService.updateGradTable(gradTable));
    }

    /**
     * 删除A类
     */
    @PreAuthorize("@ss.hasPermi('system:grad:remove')")
    @Log(title = "A类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gradTableService.deleteGradTableByIds(ids));
    }
}
